@@ -279,8 +279,11 @@ sub new {
 
         if ( !$object ) {
             $object = _object_factory( $block, $value ) unless $object;
-        } elsif ($attribute) {
+        } elsif ($object->can($attribute)) {
             $object->$attribute($value);
+        } else {
+            warn "Objects of type " . ref($object)
+                . " do not support attribute '$attribute', but it was supplied with value '$value'\n";
         }
 
     }
@@ -564,17 +567,37 @@ sub syncupdates_create {
         }
     }
 
-    my ($key) = $self->attributes('primary');
-
     my $res = $self->_syncupdates_submit( $self->dump($dump_options), $options );
 
     if (    $res =~ /^Number of objects processed with errors:\s+(\d+)/m
          && $1 == 0
-         && $res =~ /\*\*\*Info:\s+Authorisation for\s+\[[^\]]+]\s+(.+)\s*$/m )
+         && (
+                 $res =~ /\*\*\*Info:\s+Authorisation for\s+\[[^\]]+]\s+(.+)\s*$/m
+              || $res =~ /(?:Create SUCCEEDED|No operation): \[[^\]]+\]\s+(\S+)/m
+            )
+       )
     {
         my $value = $1;
-        $self->_single_attribute_setget( $key, $value );
-        return $value;
+        my ( $key ) = $self->attributes( 'primary' );
+        # some primary keys can contain spaces, in which case $value
+        # is not correct. So only use it for objects where the primary
+        # key can be generated by the RIPE DB, and where it never contains
+        # spaces. According to
+        # http://www.ripe.net/ripe/mail/archives/db-help/2013-January/000411.html
+        # this is the case for person, organization, role and key-cert
+        my %obj_types_with_autogen_key = (
+            KeyCert      => 1,
+            Organisation => 1,
+            Person       => 1,
+            Role         => 1,
+        );
+        if ($self->class && $obj_types_with_autogen_key{$self->class}) {
+            $self->_single_attribute_setget( $key, $value );
+            return $value;
+        }
+        else {
+            return $self->$key();
+        }
     } else {
         croak "Error while creating object through syncupdates API: $res";
     }
